==> scribus_1.5.5+dfsg.orig.tar.xz: scribus-1.5.5/scribus/ui/pdfversionmodel.h <==
/*
For general Scribus (>=1.3.2) copyright and licensing information please refer
to the COPYING file provided with the program. Following this notice may exist
a copyright and/or license notice that predates the release of Scribus 1.3.2
for which a new license (GPL+exception) is in place.
*/
#ifndef PDFVERSIONMODEL_H
#define PDFVERSIONMODEL_H

#include <QAbstractItemModel>
#include <QVector>

#include "scribusapi.h"

class ScribusDoc;

class SCRIBUS_API PdfVersionModel : public QAbstractItemModel
{
	Q_OBJECT

public:
	//! Constructor
	PdfVersionModel(QObject *parent = 0);
	
	enum PdfVersionItem
	{
		ItemPDF_13 = 0,
		ItemPDF_14 = 1,
		ItemPDF_15 = 2,
		ItemPDFX_1a = 3,
		ItemPDFX_3  = 4,
		ItemPDFX_4  = 5
	};

	//! Remove all colors from list;
	void clear();

	//! Reimplement QAbstractItemModel columnCount()
	int columnCount(const QModelIndex &parent = QModelIndex()) const;

	//! Reimplement QAbstractItemModel data()
	QVariant data(const QModelIndex &index, int role) const;

	//! Reimplement QAbstractItemModel flags()
	Qt::ItemFlags flags(const QModelIndex &index) const;

	//! Reimplement QAbstractItemModel index()
	QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const;

	//! Reimplement QAbstractItemModel parent()
	QModelIndex parent(const QModelIndex &child) const;

	//! Reimplement QAbstractItemModel removeRow()
	bool removeRow(int row, const QModelIndex& parent = QModelIndex());

	//! Reimplement QAbstractItemModel removeRowz()
	bool removeRows(int row, int count, const QModelIndex& parent = QModelIndex());

	//! Reimplement QAbstractItemModel rowCount()
	int rowCount(const QModelIndex &parent = QModelIndex()) const;
	
	//! Allow or disallow no font embedding mode
	void setPdfXEnabled(bool enabled);

protected:
	//! The color list
	QVector<bool> m_enabledVec;
};

#endif // PDFVERSIONMODEL_H

==> scribus_1.5.6.1+dfsg.orig.tar.xz: scribus-1.5.6.1/scribus/ui/pdfversionmodel.h <==
/*
For general Scribus (>=1.3.2) copyright and licensing information please refer
to the COPYING file provided with the program. Following this notice may exist
a copyright and/or license notice that predates the release of Scribus 1.3.2
for which a new license (GPL+exception) is in place.
*/
#ifndef PDFVERSIONMODEL_H
#define PDFVERSIONMODEL_H

#include <QAbstractItemModel>
#include <QVector>

#include "scribusapi.h"

class ScribusDoc;

class SCRIBUS_API PdfVersionModel : public QAbstractItemModel
{
	Q_OBJECT

public:
	//! Constructor
	PdfVersionModel(QObject* parent = nullptr);
	
	enum PdfVersionItem
	{
		ItemPDF_13 = 0,
		ItemPDF_14 = 1,
		ItemPDF_15 = 2,
		ItemPDF_16 = 3,
		ItemPDFX_1a = 4,
		ItemPDFX_3  = 5,
		ItemPDFX_4  = 6
	};

	//! Remove all colors from list;
	void clear();

	//! Reimplement QAbstractItemModel columnCount()
	int columnCount(const QModelIndex &parent = QModelIndex()) const;

	//! Reimplement QAbstractItemModel data()
	QVariant data(const QModelIndex &index, int role) const;

	//! Reimplement QAbstractItemModel flags()
	Qt::ItemFlags flags(const QModelIndex &index) const;

	//! Reimplement QAbstractItemModel index()
	QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const;

	//! Reimplement QAbstractItemModel parent()
	QModelIndex parent(const QModelIndex &child) const;

	//! Reimplement QAbstractItemModel removeRow()
	bool removeRow(int row, const QModelIndex& parent = QModelIndex());

	//! Reimplement QAbstractItemModel removeRowz()
	bool removeRows(int row, int count, const QModelIndex& parent = QModelIndex());

	//! Reimplement QAbstractItemModel rowCount()
	int rowCount(const QModelIndex &parent = QModelIndex()) const;
	
	//! Allow or disallow no font embedding mode
	void setPdfXEnabled(bool enabled);

protected:
	//! The color list
	QVector<bool> m_enabledVec;
};

#endif // PDFVERSIONMODEL_H
